# frozen_string_literal: true

module Bulkrax
  class CrcFolderComplexSubjectEntry < CrcFolderEntry
    def build
      begin
        raise CrcDatasetCreatedError unless crc_dataset_created?

        complex_subject = ComplexSubject.new(self.raw_metadata.slice('subject_species', 'subject_type', 'subject_sex', 'subject_age'))
        complex_subject.subject_title = raw_metadata['title']
        complex_subject.source_identifier = identifier
        complex_subject.parent_source_identifier = self.raw_metadata['parents']

        complex_subject.save!
      rescue RSolr::Error::Http, CrcDatasetCreatedError => e
        raise e
      rescue StandardError => e
        status_info(e)
      else
        status_info
      ensure
        self.save!
      end
    end

    def factory_class
      ComplexSubject
    end

    def crc_dataset_created?
      ::CrcDataset.where(source: self.raw_metadata['parents']).present?
    end
  end
end
